==========
Exceptions
==========

.. py:class:: ValidationError

   Simple import from jsonschema errors


.. automodule:: pyrs.schema.exceptions
    :members:
    :undoc-members:
    :show-inheritance:
